@@ -38,11 +38,11 @@
 #include <tqsocket.h>
 #include <tqsocketdevice.h>
 
-#include <klocale.h>
+#include <tdelocale.h>
 #include <kdebug.h>
-#include <kio/netaccess.h>
+#include <tdeio/netaccess.h>
 #include <kstandarddirs.h>
-#include <ktempfile.h>
+#include <tdetempfile.h>
 
 #include <sys/types.h>
 #include <sys/socket.h>
@@ -459,15 +459,15 @@ void K3bCdrdaoWriter::start()
 
   d->speedEst->reset();
 
-  delete m_process;  // kdelibs want this!
+  delete m_process;  // tdelibs want this!
   m_process = new K3bProcess();
   m_process->setRunPrivileged(true);
   m_process->setSplitStdout(false);
   m_process->setRawStdin(true);
   connect( m_process, TQT_SIGNAL(stderrLine(const TQString&)),
            this, TQT_SLOT(slotStdLine(const TQString&)) );
-  connect( m_process, TQT_SIGNAL(processExited(KProcess*)),
-           this, TQT_SLOT(slotProcessExited(KProcess*)) );
+  connect( m_process, TQT_SIGNAL(processExited(TDEProcess*)),
+           this, TQT_SLOT(slotProcessExited(TDEProcess*)) );
 
   m_canceled = false;
   m_knownError = false;
@@ -516,7 +516,7 @@ void K3bCdrdaoWriter::start()
 	    m_backupTocFile = m_tocFile + ".k3bbak";
 
 	    // workaround, cdrdao deletes the tocfile when --remote parameter is set
-	    if ( !KIO::NetAccess::copy(KURL(m_tocFile),KURL(m_backupTocFile), (TQWidget*) 0) )
+	    if ( !TDEIO::NetAccess::copy(KURL(m_tocFile),KURL(m_backupTocFile), (TQWidget*) 0) )
 	      {
 		kdDebug() << "(K3bCdrdaoWriter) could not backup " << m_tocFile << " to " << m_backupTocFile << endl;
 		emit infoMessage( i18n("Could not backup tocfile."), ERROR );
@@ -577,7 +577,7 @@ void K3bCdrdaoWriter::start()
   burnDevice()->close();
   burnDevice()->usageLock();
 
-  if( !m_process->start( KProcess::NotifyOnExit, KProcess::AllOutput ) )
+  if( !m_process->start( TDEProcess::NotifyOnExit, TDEProcess::AllOutput ) )
     {
       // something went wrong when starting the program
       // it "should" be the executable
@@ -709,7 +709,7 @@ void K3bCdrdaoWriter::slotStdLine( const TQString& line )
 }
 
 
-void K3bCdrdaoWriter::slotProcessExited( KProcess* p )
+void K3bCdrdaoWriter::slotProcessExited( TDEProcess* p )
 {
   // release the device within this process
   burnDevice()->usageUnlock();
@@ -722,20 +722,20 @@ void K3bCdrdaoWriter::slotProcessExited( KProcess* p )
   case WRITE:
   case COPY:
     if ( !m_binFileLnk.isEmpty() ) {
-        KIO::NetAccess::del(KURL::fromPathOrURL(m_cueFileLnk), (TQWidget*) 0);
-        KIO::NetAccess::del(KURL::fromPathOrURL(m_binFileLnk), (TQWidget*) 0);
+        TDEIO::NetAccess::del(KURL::fromPathOrURL(m_cueFileLnk), (TQWidget*) 0);
+        TDEIO::NetAccess::del(KURL::fromPathOrURL(m_binFileLnk), (TQWidget*) 0);
     }
     else if( (!TQFile::exists( m_tocFile ) || K3b::filesize( KURL::fromPathOrURL(m_tocFile) ) == 0 ) && !m_onTheFly )
     {
       // cdrdao removed the tocfile :(
       // we need to recover it
-      if ( !KIO::NetAccess::copy(KURL::fromPathOrURL(m_backupTocFile), KURL::fromPathOrURL(m_tocFile), (TQWidget*) 0) )
+      if ( !TDEIO::NetAccess::copy(KURL::fromPathOrURL(m_backupTocFile), KURL::fromPathOrURL(m_tocFile), (TQWidget*) 0) )
       {
         kdDebug() << "(K3bCdrdaoWriter) restoring tocfile " << m_tocFile << " failed." << endl;
         emit infoMessage( i18n("Due to a bug in cdrdao the toc/cue file %1 has been deleted. "
                                "K3b was unable to restore it from the backup %2.").arg(m_tocFile).arg(m_backupTocFile), ERROR );
       }
-      else if ( !KIO::NetAccess::del(KURL::fromPathOrURL(m_backupTocFile), (TQWidget*) 0) )
+      else if ( !TDEIO::NetAccess::del(KURL::fromPathOrURL(m_backupTocFile), (TQWidget*) 0) )
       {
         kdDebug() << "(K3bCdrdaoWriter) delete tocfile backkup " << m_backupTocFile << " failed." << endl;
       }
@@ -775,7 +775,7 @@ void K3bCdrdaoWriter::slotProcessExited( KProcess* p )
 
       if( m_command == WRITE || m_command == COPY ) {
 	int s = d->speedEst->average();
-	emit infoMessage( i18n("Average overall write speed: %1 KB/s (%2x)").arg(s).arg(KGlobal::locale()->formatNumber((double)s/150.0), 2), INFO );
+	emit infoMessage( i18n("Average overall write speed: %1 KB/s (%2x)").arg(s).arg(TDEGlobal::locale()->formatNumber((double)s/150.0), 2), INFO );
       }
 
       jobFinished( true );
@@ -936,7 +936,7 @@ void K3bCdrdaoWriter::parseCdrdaoWrote( const TQString& line )
 
 void K3bCdrdaoWriter::parseCdrdaoMessage()
 {
-  static const char msgSync[] = { 0xff, 0x00, 0xff, 0x00 };
+  static const char msgSync[] = { '\xff', '\x00', '\xff', '\x00' };
   unsigned int avail = m_comSock->bytesAvailable();
   unsigned int msgs = avail / ( sizeof(msgSync)+d->progressMsgSize );
   unsigned int count = 0;
