@@ -41,14 +41,14 @@
 #include <k3bsignalwaiter.h>
 #include <k3bexternalbinmanager.h>
 
-#include <klocale.h>
+#include <tdelocale.h>
 #include <kurl.h>
 #include <kinputdialog.h>
-#include <kmessagebox.h>
+#include <tdemessagebox.h>
 #include <kiconloader.h>
-#include <kglobal.h>
+#include <tdeglobal.h>
 #include <kstdguiitem.h>
-#include <kconfig.h>
+#include <tdeconfig.h>
 #include <ksqueezedtextlabel.h>
 #include <kprogress.h>
 
@@ -181,7 +181,7 @@ TQString K3bDataUrlAddingDialog::resultMessage() const
       .arg( m_unreadableFiles.join( "<br>" ) );
   if( !m_tooBigFiles.isEmpty() )
     message += TQString("<p><b>%1:</b><br>%2")
-      .arg( i18n("It is not possible to add files bigger than %1").arg(KIO::convertSize(0xFFFFFFFF)) )
+      .arg( i18n("It is not possible to add files bigger than %1").arg(TDEIO::convertSize(0xFFFFFFFF)) )
       .arg( m_tooBigFiles.join( "<br>" ) );
   if( !m_mkisofsLimitationRenamedFiles.isEmpty() )
     message += TQString("<p><b>%1:</b><br>%2")
@@ -562,8 +562,8 @@ void K3bDataUrlAddingDialog::slotAddUrls()
       int dirFilter = TQDir::All|TQDir::Hidden|TQDir::System;
 
       TQStringList dlist = newDir.entryList( dirFilter );
-      const TQString& dot = KGlobal::staticQString( "." );
-      const TQString& dotdot = KGlobal::staticQString( ".." );
+      const TQString& dot = TDEGlobal::staticQString( "." );
+      const TQString& dotdot = TDEGlobal::staticQString( ".." );
       dlist.remove( dot );
       dlist.remove( dotdot );
 
