@@ -37,7 +37,7 @@ class TQPainter;
 
 class K3bVcdListView : public K3bListView
 {
-        Q_OBJECT
+        TQ_OBJECT
   
 
     public:
